==> 6.6.4.tar.gz: lib/XWidgets/XTextFormField/XTextFormFieldWithDD.dart <==
part of xwidgetbase;

class XTextFormFieldWithDD extends StatelessWidget {
  final String? label;
  final String hintText;
  final ValueChanged<String>? onChanged;
  final ValueChanged<String?>? onChangedDropDown;
  final TextInputType keyboardType;
  final Function(String?)? onFieldSubmitted;
  final Function(String?)? onSaved;
  final Function? onPressedBTNSave;
  final Function? validator;
  final Function? onEditingComplete;
  final FocusNode? focusNode;
  final bool isPassword;
  final bool multiLines;
  final bool isVisibleBTNsave;
  final bool isVisibleDropDown;
  final bool showSearchBox;
  final double? width;
  final double maxHeight;
  final int? maxLines;
  final double? height;
  final TextInputAction textInputAction;
  final TextEditingController? controller;
  final AutovalidateMode? autovalidateMode;
  final String? initialValue;
  final TextStyle? labelStyle;
  GestureTapCallback? onTap;
  final List<String>? ddItems;
  List<TextInputFormatter>? inputFormatters;
  final Color? textColor;
  final FloatingLabelBehavior? floatingLabelBehaviorActive;
  final InputBorder? border;
  final InputBorder? disabledBorder;
  final InputBorder? enabledBorder;
  final InputBorder? focusedBorder;
  final TextStyle? hintStyle;
  final EdgeInsetsGeometry? contentPadding;
  final Widget? suffixIcon;
  final bool? isDenseTextFormField;
  final Color? colorBorder;
  final int? maxLenght;
  final String? labelDD;
  final String? hintTextDD;
  final Mode? modeDD;
  final bool? showClearButton;
  final Color? focusColor;
  final Color? fillColor;
  final bool autoFocus;
  final bool borderVisible;

  XTextFormFieldWithDD(
      {this.label,
      this.hintText = '',
      this.focusColor,
      this.fillColor,
      this.focusedBorder,
      this.colorBorder,
      this.labelDD,
      this.borderVisible = true,
      this.hintTextDD,
      this.modeDD,
      this.showClearButton = true,
      this.border,
      this.suffixIcon,
      this.contentPadding,
      this.isDenseTextFormField = true,
      this.enabledBorder,
      this.disabledBorder,
      this.floatingLabelBehaviorActive,
      this.hintStyle,
      this.labelStyle,
      this.onEditingComplete,
      this.initialValue,
      this.ddItems,
      this.inputFormatters,
      this.isVisibleBTNsave = false,
      this.isVisibleDropDown = false,
      this.controller,
      this.onPressedBTNSave,
      this.width,
      this.textColor,
      this.onTap,
      this.maxLines,
      this.height,
      this.maxHeight = 500,
      this.showSearchBox = false,
      this.onChanged,
      this.onChangedDropDown,
      this.multiLines = false,
      this.keyboardType = TextInputType.text,
      this.textInputAction = TextInputAction.next,
      this.onFieldSubmitted,
      this.onSaved,
      this.validator,
      this.focusNode,
      this.autovalidateMode,
      this.maxLenght,
      this.autoFocus = false,
      this.isPassword = false});

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Stack(
        alignment: Alignment.bottomRight,
        children: <Widget>[
          Column(children: <Widget>[
            Container(
              width: width,
              height: height,
              child: TextFormField(
                  autofocus: autoFocus,
                  initialValue: initialValue,
                  controller: controller,
                  onTap: onTap,
                  focusNode: focusNode,
                  keyboardType: (multiLines ? TextInputType.multiline : keyboardType),
                  style: labelStyle ?? TextStyle(color: textColor ?? Colors.white),
                  textInputAction: (multiLines ? TextInputAction.newline : textInputAction),
                  onFieldSubmitted: onFieldSubmitted,
                  obscureText: isPassword,
                  strutStyle: StrutStyle(height: height, fontSize: 18, forceStrutHeight: true),
                  onSaved: onSaved,
                  onEditingComplete: onEditingComplete as void Function()?,
                  onChanged: onChanged,
                  inputFormatters: inputFormatters ?? [],
                  maxLines: maxLines,
                  maxLength: maxLenght,
                  autovalidateMode: autovalidateMode,
                  validator: validator as String? Function(String?)?,
                  decoration: InputDecoration(
                    isDense: isDenseTextFormField,
                    floatingLabelBehavior: floatingLabelBehaviorActive ?? FloatingLabelBehavior.always,
                    contentPadding: contentPadding ?? EdgeInsets.only(top: 20, left: 5, bottom: 1),
                    border: borderVisible == true ? border ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    disabledBorder: borderVisible == true ? disabledBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    enabledBorder: borderVisible == true ? enabledBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    focusedBorder: borderVisible == true ? focusedBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    focusColor: focusColor ?? Colors.white,
                    fillColor: fillColor ?? Colors.white,
                    labelText: label,
                    suffixIcon: suffixIcon,
                    hintText: hintText,
                    labelStyle: labelStyle,
                    hintStyle: hintStyle ??
                        TextStyle(
                          color: textColor ?? Colors.white,
                        ),
                  )),
            ),
            isVisibleDropDown == false
                ? SizedBox(height: 5)
                : Container(
                    alignment: Alignment.center,
                    color: Colors.black26,
                    child: DropdownSearch<String>(
                      hint: hintTextDD ?? "seleziona la Frase predefinita che preferisci.",
                      mode: modeDD ?? Mode.MENU,
                      label: labelDD ?? "Frasi Predefinite",
                      itemAsString: (u) => u,
                      showSearchBox: showSearchBox,
                      maxHeight: maxHeight,
                      showClearButton: showClearButton!,
                      onChanged: onChangedDropDown,
                      items: ddItems,
                    ),
                  ),
          ]),
          isVisibleBTNsave == true
              ? Container(
                  alignment: Alignment.bottomRight,
                  height: 40,
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    crossAxisAlignment: CrossAxisAlignment.end,
                    children: <Widget>[
                      Container(
                          padding: EdgeInsets.fromLTRB(0, 0, 0, 5),
                          child: ElevatedButton(
                            style: ElevatedButton.styleFrom(
                              elevation: 1,
                              primary: Colors.transparent,
                            ),
                            onPressed: onPressedBTNSave as void Function()?,
                            child: Icon(
                              Icons.done,
                              color: Colors.greenAccent,
                            ),
                          )),
                      SizedBox(
                        width: 5,
                      ),
                    ],
                  ),
                )
              : Container()
        ],
      ),
    );
  }
}

==> 11.3.0.tar.gz: lib/XWidgets/XTextFormField/XTextFormFieldWithDD.dart <==
part of xwidgetbase;

class XTextFormFieldWithDD extends StatelessWidget {
  final String? label;
  final String hintText;
  final ValueChanged<String>? onChanged;
  final ValueChanged<String?>? onChangedDropDown;
  final TextInputType keyboardType;
  final Function(String?)? onFieldSubmitted;
  final Function(String?)? onSaved;
  final Function? onPressedBTNSave;
  final Function? validator;
  final Function? onEditingComplete;
  final FocusNode? focusNode;
  final bool isPassword;
  final bool multiLines;
  final bool isVisibleBTNsave;
  final bool isVisibleDropDown;
  final bool showSearchBox;
  final double? width;
  final double maxHeight;
  final int? maxLines;
  final double? height;
  final TextInputAction textInputAction;
  final TextEditingController? controller;
  final AutovalidateMode? autovalidateMode;
  final String? initialValue;
  final TextStyle? labelStyle;
  GestureTapCallback? onTap;
  final List<String>? ddItems;
  List<TextInputFormatter>? inputFormatters;
  final Color? textColor;
  final FloatingLabelBehavior? floatingLabelBehaviorActive;
  final InputBorder? border;
  final InputBorder? disabledBorder;
  final InputBorder? enabledBorder;
  final InputBorder? focusedBorder;
  final TextStyle? hintStyle;
  final EdgeInsetsGeometry? contentPadding;
  final Widget? suffixIcon;
  final bool? isDenseTextFormField;
  final Color? colorBorder;
  final int? maxLenght;
  final String? labelDD;
  final String? hintTextDD;
  final Mode? modeDD;
  final bool? showClearButton;
  final Color? focusColor;
  final Color? fillColor;
  final bool autoFocus;
  final bool borderVisible;

  XTextFormFieldWithDD(
      {this.label,
      this.hintText = '',
      this.focusColor,
      this.fillColor,
      this.focusedBorder,
      this.colorBorder,
      this.labelDD,
      this.borderVisible = true,
      this.hintTextDD,
      this.modeDD,
      this.showClearButton = true,
      this.border,
      this.suffixIcon,
      this.contentPadding,
      this.isDenseTextFormField = true,
      this.enabledBorder,
      this.disabledBorder,
      this.floatingLabelBehaviorActive,
      this.hintStyle,
      this.labelStyle,
      this.onEditingComplete,
      this.initialValue,
      this.ddItems,
      this.inputFormatters,
      this.isVisibleBTNsave = false,
      this.isVisibleDropDown = false,
      this.controller,
      this.onPressedBTNSave,
      this.width,
      this.textColor,
      this.onTap,
      this.maxLines,
      this.height,
      this.maxHeight = 500,
      this.showSearchBox = false,
      this.onChanged,
      this.onChangedDropDown,
      this.multiLines = false,
      this.keyboardType = TextInputType.text,
      this.textInputAction = TextInputAction.next,
      this.onFieldSubmitted,
      this.onSaved,
      this.validator,
      this.focusNode,
      this.autovalidateMode,
      this.maxLenght,
      this.autoFocus = false,
      this.isPassword = false});

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Stack(
        alignment: Alignment.bottomRight,
        children: <Widget>[
          Column(children: <Widget>[
            Container(
              width: width,
              height: height,
              child: TextFormField(
                  autofocus: autoFocus,
                  initialValue: initialValue,
                  controller: controller,
                  onTap: onTap,
                  focusNode: focusNode,
                  keyboardType: (multiLines ? TextInputType.multiline : keyboardType),
                  style: labelStyle ?? TextStyle(color: textColor ?? Colors.white),
                  textInputAction: (multiLines ? TextInputAction.newline : textInputAction),
                  onFieldSubmitted: onFieldSubmitted,
                  obscureText: isPassword,
                  strutStyle: StrutStyle(height: height, fontSize: 18, forceStrutHeight: true),
                  onSaved: onSaved,
                  onEditingComplete: onEditingComplete as void Function()?,
                  onChanged: onChanged,
                  inputFormatters: inputFormatters ?? [],
                  maxLines: maxLines,
                  maxLength: maxLenght,
                  autovalidateMode: autovalidateMode,
                  validator: validator as String? Function(String?)?,
                  decoration: InputDecoration(
                    isDense: isDenseTextFormField,
                    floatingLabelBehavior: floatingLabelBehaviorActive ?? FloatingLabelBehavior.always,
                    contentPadding: contentPadding ?? EdgeInsets.only(top: 20, left: 5, bottom: 1),
                    border: borderVisible == true ? border ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    disabledBorder: borderVisible == true ? disabledBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    enabledBorder: borderVisible == true ? enabledBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    focusedBorder: borderVisible == true ? focusedBorder ?? OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(4.0)), borderSide: BorderSide(width: 1, color: colorBorder ?? Colors.white), gapPadding: 3) : InputBorder.none,
                    focusColor: focusColor ?? Colors.white,
                    fillColor: fillColor ?? Colors.white,
                    labelText: label,
                    suffixIcon: suffixIcon,
                    hintText: hintText,
                    labelStyle: labelStyle,
                    hintStyle: hintStyle ??
                        TextStyle(
                          color: textColor ?? Colors.white,
                        ),
                  )),
            ),
            // isVisibleDropDown == false
            //     ? SizedBox(height: 5)
            //     : Container(
            //         alignment: Alignment.center,
            //         color: Colors.black26,
            //         child: DropdownSearch<String>(
            //           hint: hintTextDD ?? "seleziona la Frase predefinita che preferisci.",
            //           mode: modeDD ?? Mode.MENU,
            //           label: labelDD ?? "Frasi Predefinite",
            //           itemAsString: (u) => u,
            //           showSearchBox: showSearchBox,
            //           maxHeight: maxHeight,
            //           showClearButton: showClearButton!,
            //           onChanged: onChangedDropDown,
            //           items: ddItems,
            //         ),
            //       ),
          ]),
          isVisibleBTNsave == true
              ? Container(
                  alignment: Alignment.bottomRight,
                  height: 40,
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    crossAxisAlignment: CrossAxisAlignment.end,
                    children: <Widget>[
                      Container(
                          padding: EdgeInsets.fromLTRB(0, 0, 0, 5),
                          child: ElevatedButton(
                            style: ElevatedButton.styleFrom(
                              elevation: 1,
                              backgroundColor: Colors.transparent,
                            ),
                            onPressed: onPressedBTNSave as void Function()?,
                            child: Icon(
                              Icons.done,
                              color: Colors.greenAccent,
                            ),
                          )),
                      SizedBox(
                        width: 5,
                      ),
                    ],
                  ),
                )
              : Container()
        ],
      ),
    );
  }
}
